==> haskell-hpack-0.31.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.31.0
id: hpack-0.31.0-2za5uQyHOJO2W71Z4Gapfp
key: hpack-0.31.0-2za5uQyHOJO2W71Z4Gapfp
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 6fddaafde040ddbbccdd2e3c2e4ebcac
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.31.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.31.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hpack-0.31.0
hs-libraries: HShpack-0.31.0-2za5uQyHOJO2W71Z4Gapfp
depends:
    Cabal-2.2.0.1 Glob-0.9.2-HJ6eAu8fFh08wRJGfeL7G1
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX base-4.11.1.0
    bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69 bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13.1-Ix7fmogA1Hj11uABzfxUxL
    http-client-tls-0.3.5.3-6XXmycQeLrC1fP2aS1Msko
    http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz
    infer-license-0.2.0-H0VO6Nef5S3Bd3kqhWYIkI pretty-1.1.3.6
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.10.2.0-HPK1HZ2mtMRA6k4rGyfIZD
abi-depends: Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             Glob-0.9.2-HJ6eAu8fFh08wRJGfeL7G1=45e5e2356859721fffc205bcf8d3fea2
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69=8adb81346affd1af6f03238f8ca73e7f
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-client-0.5.13.1-Ix7fmogA1Hj11uABzfxUxL=b5bbbb2416b8c71b835e8b7e040cae41
             http-client-tls-0.3.5.3-6XXmycQeLrC1fP2aS1Msko=2358351eea6016335b2e106bccc9f333
             http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz=83a424f80f062f589a336c1b654188f8
             infer-license-0.2.0-H0VO6Nef5S3Bd3kqhWYIkI=0b67f8948925045adc04411cbb7457bf
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             yaml-0.10.2.0-HPK1HZ2mtMRA6k4rGyfIZD=808e90aa00cb4d4d5c64d4ad7ba85f15
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.31.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.31.0
id: hpack-0.31.0-GLfwVnHiKki1O4areBdNdE
key: hpack-0.31.0-GLfwVnHiKki1O4areBdNdE
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 2e3b588493251e10a15474184f897c76
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.31.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hpack-0.31.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hpack-0.31.0
hs-libraries: HShpack-0.31.0-GLfwVnHiKki1O4areBdNdE
depends:
    Cabal-2.2.0.1 Glob-0.9.3-EWfWGrcNvnJ8DspgY55ZzU
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX base-4.11.1.0
    bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69 bytestring-0.10.8.2
    containers-0.5.11.0 cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    http-client-0.5.13.1-4FGgNXaIPaRFFyHndQhLfa
    http-client-tls-0.3.5.3-EjRrcncVg5f6mnKyjdfLJe
    http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH
    infer-license-0.2.0-H0VO6Nef5S3Bd3kqhWYIkI pretty-1.1.3.6
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    yaml-0.10.2.0-HPK1HZ2mtMRA6k4rGyfIZD
abi-depends: Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             Glob-0.9.3-EWfWGrcNvnJ8DspgY55ZzU=7b0a0165fcbc107cec927754704dddde
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.3-B2s1kTwvG5P67s9a0vFF69=8adb81346affd1af6f03238f8ca73e7f
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-client-0.5.13.1-4FGgNXaIPaRFFyHndQhLfa=602a225eaa1cdcb9d9c8364c693edb16
             http-client-tls-0.3.5.3-EjRrcncVg5f6mnKyjdfLJe=d0a4fdcc5f61421bacdc690c38cb0b16
             http-types-0.12.2-J7rsnBvQDs89qTHkldL6BH=b88dec2e9e51949b7c6a738f8b360494
             infer-license-0.2.0-H0VO6Nef5S3Bd3kqhWYIkI=0b67f8948925045adc04411cbb7457bf
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             yaml-0.10.2.0-HPK1HZ2mtMRA6k4rGyfIZD=808e90aa00cb4d4d5c64d4ad7ba85f15
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
